camelot.camelot.view.controls.delegates.FloatColumnDelegate

Package camelot :: Package camelot :: Package view :: Package controls :: Module delegates :: Class FloatColumnDelegate |
[hide private]
[frames] | no frames]

# Class FloatColumnDelegate

source code

Custom delegate for float values

Instance Methods | [hide private]
__init__(self, minimum=-100.0, maximum=100.0, precision=3, editable=True, parent=None, **kwargs) | source code
createEditor(self, parent, option, index) | source code
setEditorData(self, editor, index) | source code
setModelData(self, editor, model, index) | source code